#!/bin/sh
#   Copyright (c) 2010 digitalSTROM.org, Zurich, Switzerland
#
#   Author: Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
#
#   This file is part of digitalSTROM Server.
#
#   netinfo.sh is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   netinfo.sh is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this file. If not, see <http://www.gnu.org/licenses/>.

# source common functions
. ./errlib.sh
. ./jsonlib.sh


echo "Content-Type: application/json"
echo ""

print_gmt_offset() {
    MAX_MINUTES=60
    TEMP_GMTOFFSET=`date +%z`
    SIGN=${TEMP_GMTOFFSET:0:1}
    HOURS=${TEMP_GMTOFFSET:1:2}
    if [[ "$SIGN" != "-" ]]; then
        SIGN=""
    fi
    if [[ ${HOURS:0:1} -eq 0 ]]; then
        HOURS=${HOURS:1:2}
    fi

    MINUTES=${TEMP_GMTOFFSET:3}

    RES=0
    if [[ $MINUTES -gt 0 ]]; then
        RES=$(($MAX_MINUTES / $MINUTES))
    fi
    echo -n "\"gmtoffset\": $SIGN$HOURS.$RES, "
}

print_zones() {
    COMMA=""
    echo -n "\"zonelist\": [ "
    if [[ ! -d /usr/share/zoneinfo/ ]]; then
	echo -n " ] " 
    	return $ERR_NOZONE
    fi

    for line in `find /usr/share/zoneinfo/ -type f | egrep -v '\.tab' `; 
        do 
            ZONE="${line:20}"

            if [[ "$ZONE" == "" ]]; then
                continue
            fi
            
            echo -n "$COMMA\"$ZONE\""
            COMMA=", " 
	done
    echo -n " ] "

    return $ERR_OK
}

print_ntpsettings() {
    echo -n "\"ntp\": "

    if [[ ! -f /etc/default/ntpclient ]]; then
        echo -n "false, "
        return $ERR_NONTP
    fi

    . /etc/default/ntpclient

    if [[ "$ENABLED" == "yes" ]]; then
        echo -n "true, "
    else
        echo -n "false, "
    fi

    return $ERR_OK 
}

print_timesettings() {
    DATE=`date +%d-%m-%Y`
    TIME=`date +%T`
    UTC=`date -u +%s`
    ZONE=`date +%Z`
    if [[ "$ZONE" == "BST" ]]; then
        ZONE="Europe/London"
    fi

    echo -n "\"date\": \"$DATE\", \"time\": \"$TIME\", \"utcsecs\": $UTC, \"zoneshort\": \"$ZONE\", "
    return $ERR_OK
}

print_zoneinfo() {
    CURRENT_TIMEZONE=""
    DEFAULT_ZONE="Europe/London"    
    if [[ ! -L /etc/localtime ]]; then
        if [[ ! -f /etc/localtime ]]; then
            # file does not exist, create default (GMT)
            if [[ -f "/usr/share/zoneinfo/$DEFAULT_ZONE" ]]; then
                ln -s "/usr/share/zoneinfo/$DEFAULT_ZONE" /etc/localtime
                CURRENT_TIMEZONE="$DEFAULT_ZONE"
            fi
        fi
    # localtime exists and is a link, pasre it
    else
        LINK=`readlink /etc/localtime`
        CURRENT_TIMEZONE="${LINK:20}"
    fi

    if [[ -z "$CURRENT_TIMEZONE" ]]; then
        CURRENT_TIMEZONE=`date +%Z`
    fi

    echo -n "\"timezone\": \"$CURRENT_TIMEZONE\""
}

# dateinfo script never fails completely

echo -n "{ \"success\": true, code: $ERR_OK, \"message\": \"OK\", \"data\": { "
print_ntpsettings
print_timesettings
print_gmt_offset
print_zoneinfo
if [[ -z "$1" ]]; then
    echo -n ", "
    print_zones
fi
echo " } }"
